pub struct HistoryStack { /* private fields */ }Expand description
Browser-like back/forward history.
Implementations
Sourceimpl HistoryStack
impl HistoryStack
Sourcepub fn visit_entry(&mut self, entry: HistoryEntry)
pub fn visit_entry(&mut self, entry: HistoryEntry)
Visits a fully described history entry and clears the forward stack.
Sourcepub fn go_back(&mut self) -> Option<&HistoryEntry>
pub fn go_back(&mut self) -> Option<&HistoryEntry>
Moves one step back and returns the new current entry.
Sourcepub fn go_forward(&mut self) -> Option<&HistoryEntry>
pub fn go_forward(&mut self) -> Option<&HistoryEntry>
Moves one step forward and returns the new current entry.
Sourcepub fn current(&self) -> Option<&HistoryEntry>
pub fn current(&self) -> Option<&HistoryEntry>
Returns the current history entry.
Sourcepub fn can_go_back(&self) -> bool
pub fn can_go_back(&self) -> bool
Returns whether back navigation is available.
Sourcepub fn can_go_forward(&self) -> bool
pub fn can_go_forward(&self) -> bool
Returns whether forward navigation is available.
Sourcepub fn entries(&self) -> Vec<&HistoryEntry>
pub fn entries(&self) -> Vec<&HistoryEntry>
Returns all entries in display order.
Sourcepub fn current_index(&self) -> Option<usize>
pub fn current_index(&self) -> Option<usize>
Returns the current entry index in entries.